@@ -18,7 +18,7 @@
  *
  * written by:
  *
- * Alain L. Knaff			
+ * Alain L. Knaff
  * alain@knaff.lu
  *
  */
@@ -28,6 +28,7 @@
 #include "mtools.h"
 #include "msdos.h"
 #include "open_image.h"
+#include "devices.h"
 #include "plain_io.h"
 #include "llong.h"
 
@@ -64,7 +65,7 @@ static ssize_t file_io(Stream_t *Stream, char *buf, mt_off_t where, size_t len,
 	if (This->seekable && where != This->lastwhere ){
 		if(mt_lseek( This->fd, where, SEEK_SET) < 0 ){
 			perror("seek");
-			This->lastwhere = (mt_off_t) -1;
+			This->lastwhere = -1;
 			return -1;
 		}
 	}
@@ -81,7 +82,7 @@ static ssize_t file_io(Stream_t *Stream, char *buf, mt_off_t where, size_t len,
 	ret = io(This->fd, buf, len);
 
 #ifdef OS_hpux
-	if (ret == -1 && 
+	if (ret == -1 &&
 		errno == EINVAL && /* if we got EINVAL */
 		len > MAX_SCSI_LEN) {
 		This->size_limited = 1;
@@ -92,13 +93,13 @@ static ssize_t file_io(Stream_t *Stream, char *buf, mt_off_t where, size_t len,
 
 	if ( ret == -1 ){
 		perror("plain_io");
-		This->lastwhere = (mt_off_t) -1;
+		This->lastwhere = -1;
 		return -1;
 	}
 	This->lastwhere = where + ret;
 	return ret;
 }
-	
+
 
 
 static ssize_t file_read(Stream_t *Stream, char *buf,
@@ -146,9 +147,9 @@ static int init_geom_with_reg(int fd, struct device *dev,
 			return 0;
 		}
 		sectors = statbuf->st_size /
-			(dev->sector_size ? dev->sector_size : 512);
+			(mt_off_t)(dev->sector_size ? dev->sector_size : 512);
 		dev->tot_sectors =
-			(sectors > (mt_off_t) UINT32_MAX)
+			((smt_off_t) sectors > UINT32_MAX)
 			? UINT32_MAX
 			: (uint32_t) sectors;
 		return 0;
@@ -158,7 +159,7 @@ static int init_geom_with_reg(int fd, struct device *dev,
 	}
 }
 
-static int file_geom(Stream_t *Stream, struct device *dev, 
+static int file_geom(Stream_t *Stream, struct device *dev,
 		     struct device *orig_dev)
 {
 	int ret;
@@ -186,7 +187,7 @@ static int file_geom(Stream_t *Stream, struct device *dev,
 }
 
 
-static int file_data(Stream_t *Stream, time_t *date, mt_size_t *size,
+static int file_data(Stream_t *Stream, time_t *date, mt_off_t *size,
 		     int *type, uint32_t *address)
 {
 	DeclareThis(SimpleFile_t);
@@ -194,7 +195,7 @@ static int file_data(Stream_t *Stream, time_t *date, mt_size_t *size,
 	if(date)
 		*date = This->statbuf.st_mtime;
 	if(size)
-		*size = (mt_size_t) This->statbuf.st_size;
+		*size = This->statbuf.st_size;
 	if(type)
 		*type = S_ISDIR(This->statbuf.st_mode);
 	if(address)
@@ -202,7 +203,7 @@ static int file_data(Stream_t *Stream, time_t *date, mt_size_t *size,
 	return 0;
 }
 
-static int file_discard(Stream_t *Stream)
+static int file_discard(Stream_t *Stream UNUSEDP)
 {
 #ifdef BLKFLSBUF
 	int ret;
@@ -217,7 +218,7 @@ static int file_discard(Stream_t *Stream)
 }
 
 static Class_t SimpleFileClass = {
-	file_read, 
+	file_read,
 	file_write,
 	file_flush,
 	file_free,
@@ -246,7 +247,7 @@ int LockDevice(int fd, struct device *dev,
 #else
 			sprintf(errmsg,
 				"plain floppy: device \"%s\" busy (%s):",
-				(dev && strlen(dev->name) < 50) ? 
+				(dev && strlen(dev->name) < 50) ?
 				 dev->name : "unknown", strerror(errno));
 #endif
 
@@ -265,17 +266,17 @@ int LockDevice(int fd, struct device *dev,
 }
 
 Stream_t *SimpleFileOpen(struct device *dev, struct device *orig_dev,
-			 const char *name, int mode, char *errmsg, 
-			 int mode2, int locked, mt_size_t *maxSize) {
+			 const char *name, int mode, char *errmsg,
+			 int mode2, int locked, mt_off_t *maxSize) {
 	return SimpleFileOpenWithLm(dev, orig_dev, name, mode,
 				    errmsg, mode2, locked, mode, maxSize,
 				    NULL);
 }
 
 Stream_t *SimpleFileOpenWithLm(struct device *dev, struct device *orig_dev,
-			       const char *name, int mode, char *errmsg, 
+			       const char *name, int mode, char *errmsg,
 			       int mode2, int locked, int lockMode,
-			       mt_size_t *maxSize, int *geomFailure)
+			       mt_off_t *maxSize, int *geomFailure)
 {
 	SimpleFile_t *This;
 #ifdef __EMX__
@@ -309,10 +310,10 @@ APIRET rc;
 		    Free(This);
 		    if(errmsg)
 #ifdef HAVE_SNPRINTF
-			snprintf(errmsg,199,"Can't stat -: %s", 
-				strerror(errno));   
+			snprintf(errmsg,199,"Can't stat -: %s",
+				strerror(errno));
 #else
-			sprintf(errmsg,"Can't stat -: %s", 
+			sprintf(errmsg,"Can't stat -: %s",
 				strerror(errno));
 #endif
 		    return NULL;
@@ -321,7 +322,7 @@ APIRET rc;
 		return (Stream_t *) This;
 	}
 
-	
+
 	if(dev) {
 		if(!(mode2 & NO_PRIV))
 			This->privileged = IS_PRIVILEGED(dev);
@@ -360,13 +361,13 @@ APIRET rc;
 	} else
 #endif
 	    {
-		    This->fd = open(name, mode | O_LARGEFILE | O_BINARY, 
+		    This->fd = open(name, mode | O_LARGEFILE | O_BINARY,
 				    IS_NOLOCK(dev)?0444:0666);
 	    }
 
 	if(IS_PRIVILEGED(dev) && !(mode2 & NO_PRIV))
 		drop_privs();
-		
+
 	if (This->fd < 0) {
 		if(errmsg) {
 #ifdef HAVE_SNPRINTF
@@ -393,14 +394,14 @@ APIRET rc;
 	   ) {
 		if(errmsg) {
 #ifdef HAVE_SNPRINTF
-			snprintf(errmsg,199,"Can't stat %s: %s", 
+			snprintf(errmsg,199,"Can't stat %s: %s",
 				name, strerror(errno));
 #else
 			if(strlen(name) > 50) {
-			    sprintf(errmsg,"Can't stat file: %s", 
+			    sprintf(errmsg,"Can't stat file: %s",
 				    strerror(errno));
 			} else {
-			    sprintf(errmsg,"Can't stat %s: %s", 
+			    sprintf(errmsg,"Can't stat %s: %s",
 				name, strerror(errno));
 			}
 #endif
@@ -410,7 +411,7 @@ APIRET rc;
 
 	if(LockDevice(This->fd, dev, locked, lockMode, errmsg) < 0)
 		goto exit_0;
-	
+
 	/* set default parameters, if needed */
 	if (dev){
 		errno=0;
@@ -432,7 +433,7 @@ APIRET rc;
 	This->Buffer = 0;
 
 	if(maxSize)
-		*maxSize = (mt_size_t) max_off_t_seek;
+		*maxSize = max_off_t_seek;
 
 	This->lastwhere = 0;
 
